@@ -5,4 +5,4 @@
 :author: Shay Hill
 created: 12/22/2019
 """
-from .svg_ultralight import *
+from svg_ultralight.main import *
