@@ -5,4 +5,4 @@
 :author: Shay Hill
 created: 12/22/2019
 """
-from .new_element import *
+from svg_ultralight.constructors.new_element import *
