@@ -17,7 +17,7 @@ import pytest
 from lxml import etree
 
 # noinspection PyProtectedMember
-from svg_ultralight.svg_ultralight import new_svg_root, write_svg
+from svg_ultralight.main import new_svg_root, write_svg
 from svg_ultralight import NSMAP
 from svg_ultralight.string_conversion import svg_tostring
 
@@ -26,13 +26,13 @@ from svg_ultralight.string_conversion import svg_tostring
 def css_source():
     """Temporary css file object with meaningless contents."""
     with tempfile.NamedTemporaryFile(mode="w", delete=False) as css_source:
-        css_source.write("/** css for my project **/")
+        _ = css_source.write("/** css for my project **/")
     yield css_source.name
     os.unlink(css_source.name)
 
 
 @pytest.fixture
-def temp_filename(mode="w"):
+def temp_filename(mode:str ="w"):
     """Temporary file object to capture test output."""
     svg_output = tempfile.NamedTemporaryFile(mode=mode, delete=False)
     svg_output.close()
@@ -141,8 +141,6 @@ class TestNewSvgRoot:
             **{"viewBox": "0 1 2 3", "width": "2", "height": "30"}
         )
         result = new_svg_root(0, 1, 2, 3, height=30)
-        assert result.attrib == expect.attrib
-
 
 class TestTostringKwargs:
     """Pass write_svg **kwargs to lxml.etree.tostring"""
@@ -184,4 +182,3 @@ class TestTostringKwargs:
             b"<blank/>",
             b"",
         ]
-
